//[mahjong-utils](../../../index.md)/[mahjongutils.models.hand](../index.md)/[RegularHandPattern](index.md)/[tatsu](tatsu.md)

# tatsu

[common]\
open override val [tatsu](tatsu.md): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tatsu](../../mahjongutils.models/-tatsu/index.md)&gt;

搭子
